==> zio-aws-schemas_2.13-5.17.124.3-sources.jar: zio/aws/schemas/model/CreateRegistryRequest.scala <==
package zio.aws.schemas.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.schemas.model.primitives.{__string, __stringMin0Max256}
import scala.jdk.CollectionConverters._
final case class CreateRegistryRequest(
    description: Option[__stringMin0Max256] = None,
    registryName: __string,
    tags: Option[Map[__string, __string]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.schemas.model.CreateRegistryRequest = {
    import CreateRegistryRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.schemas.model.CreateRegistryRequest
      .builder()
      .optionallyWith(
        description.map(value =>
          __stringMin0Max256.unwrap(value): java.lang.String
        )
      )(_.description)
      .registryName(__string.unwrap(registryName): java.lang.String)
      .optionallyWith(
        tags.map(value =>
          value
            .map({ case (key, value) =>
              (__string.unwrap(key): java.lang.String) -> (__string
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.schemas.model.CreateRegistryRequest.ReadOnly =
    zio.aws.schemas.model.CreateRegistryRequest.wrap(buildAwsValue())
}
object CreateRegistryRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.schemas.model.CreateRegistryRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.schemas.model.CreateRegistryRequest =
      zio.aws.schemas.model.CreateRegistryRequest(
        description.map(value => value),
        registryName,
        tags.map(value => value)
      )
    def description: Option[__stringMin0Max256]
    def registryName: __string
    def tags: Option[Map[__string, __string]]
    def getDescription: ZIO[Any, AwsError, __stringMin0Max256] =
      AwsError.unwrapOptionField("description", description)
    def getRegistryName: ZIO[Any, Nothing, __string] = ZIO.succeed(registryName)
    def getTags: ZIO[Any, AwsError, Map[__string, __string]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.schemas.model.CreateRegistryRequest
  ) extends zio.aws.schemas.model.CreateRegistryRequest.ReadOnly {
    override val description: Option[__stringMin0Max256] = scala
      .Option(impl.description())
      .map(value => zio.aws.schemas.model.primitives.__stringMin0Max256(value))
    override val registryName: __string =
      zio.aws.schemas.model.primitives.__string(impl.registryName())
    override val tags: Option[Map[__string, __string]] = scala
      .Option(impl.tags())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.schemas.model.primitives
              .__string(key) -> zio.aws.schemas.model.primitives.__string(value)
          })
          .toMap
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.schemas.model.CreateRegistryRequest
  ): zio.aws.schemas.model.CreateRegistryRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-schemas_2.13-5.17.146.2-sources.jar: zio/aws/schemas/model/CreateRegistryRequest.scala <==
package zio.aws.schemas.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.schemas.model.primitives.{__string, __stringMin0Max256}
import scala.jdk.CollectionConverters._
final case class CreateRegistryRequest(
    description: Option[__stringMin0Max256] = None,
    registryName: __string,
    tags: Option[Map[__string, __string]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.schemas.model.CreateRegistryRequest = {
    import CreateRegistryRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.schemas.model.CreateRegistryRequest
      .builder()
      .optionallyWith(description.map(value => value: java.lang.String))(
        _.description
      )
      .registryName(registryName: java.lang.String)
      .optionallyWith(
        tags.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (value: java.lang.String)
            })
            .asJava
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.schemas.model.CreateRegistryRequest.ReadOnly =
    zio.aws.schemas.model.CreateRegistryRequest.wrap(buildAwsValue())
}
object CreateRegistryRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.schemas.model.CreateRegistryRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.schemas.model.CreateRegistryRequest =
      zio.aws.schemas.model.CreateRegistryRequest(
        description.map(value => value),
        registryName,
        tags.map(value => value)
      )
    def description: Option[__stringMin0Max256]
    def registryName: __string
    def tags: Option[Map[__string, __string]]
    def getDescription: ZIO[Any, AwsError, __stringMin0Max256] =
      AwsError.unwrapOptionField("description", description)
    def getRegistryName: ZIO[Any, Nothing, __string] = ZIO.succeed(registryName)
    def getTags: ZIO[Any, AwsError, Map[__string, __string]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.schemas.model.CreateRegistryRequest
  ) extends zio.aws.schemas.model.CreateRegistryRequest.ReadOnly {
    override val description: Option[__stringMin0Max256] =
      scala.Option(impl.description()).map(value => value: __stringMin0Max256)
    override val registryName: __string = impl.registryName(): __string
    override val tags: Option[Map[__string, __string]] = scala
      .Option(impl.tags())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            (key: __string) -> (value: __string)
          })
          .toMap
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.schemas.model.CreateRegistryRequest
  ): zio.aws.schemas.model.CreateRegistryRequest.ReadOnly = new Wrapper(impl)
}
